import * as cdk from "../../core";
import * as constructs from "constructs";
import * as cfn_parse from "../../core/lib/helpers-internal";
/**
 * Definition of AWS::AIOps::InvestigationGroup Resource Type.
 *
 * @cloudformationResource AWS::AIOps::InvestigationGroup
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html
 */
export declare class CfnInvestigationGroup extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggableV2 {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnInvestigationGroup from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnInvestigationGroup;
    /**
     * The Investigation Group's ARN.
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The timestamp value.
     *
     * @cloudformationAttribute CreatedAt
     */
    readonly attrCreatedAt: string;
    /**
     * User friendly name for resources.
     *
     * @cloudformationAttribute CreatedBy
     */
    readonly attrCreatedBy: string;
    /**
     * User friendly name for resources.
     *
     * @cloudformationAttribute LastModifiedAt
     */
    readonly attrLastModifiedAt: string;
    /**
     * User friendly name for resources.
     *
     * @cloudformationAttribute LastModifiedBy
     */
    readonly attrLastModifiedBy: string;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly cdkTagManager: cdk.TagManager;
    /**
     * An array of key-value pairs of notification channels to apply to this resource.
     */
    chatbotNotificationChannels?: Array<CfnInvestigationGroup.ChatbotNotificationChannelProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * An array of cross account configurations.
     */
    crossAccountConfigurations?: Array<CfnInvestigationGroup.CrossAccountConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    encryptionConfig?: CfnInvestigationGroup.EncryptionConfigMapProperty | cdk.IResolvable;
    /**
     * Investigation Group policy.
     */
    investigationGroupPolicy?: string;
    /**
     * Flag to enable cloud trail history.
     */
    isCloudTrailEventHistoryEnabled?: boolean | cdk.IResolvable;
    /**
     * User friendly name for resources.
     */
    name: string;
    /**
     * The number of days to retain the investigation group.
     */
    retentionInDays?: number;
    /**
     * The Investigation Role's ARN.
     */
    roleArn?: string;
    tagKeyBoundaries?: Array<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: Array<cdk.CfnTag>;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnInvestigationGroupProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnInvestigationGroup {
    /**
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-encryptionconfigmap.html
     */
    interface EncryptionConfigMapProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-encryptionconfigmap.html#cfn-aiops-investigationgroup-encryptionconfigmap-encryptionconfigurationtype
         */
        readonly encryptionConfigurationType?: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-encryptionconfigmap.html#cfn-aiops-investigationgroup-encryptionconfigmap-kmskeyid
         */
        readonly kmsKeyId?: string;
    }
    /**
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-chatbotnotificationchannel.html
     */
    interface ChatbotNotificationChannelProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-chatbotnotificationchannel.html#cfn-aiops-investigationgroup-chatbotnotificationchannel-chatconfigurationarns
         */
        readonly chatConfigurationArns?: Array<string>;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-chatbotnotificationchannel.html#cfn-aiops-investigationgroup-chatbotnotificationchannel-snstopicarn
         */
        readonly snsTopicArn?: string;
    }
    /**
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-crossaccountconfiguration.html
     */
    interface CrossAccountConfigurationProperty {
        /**
         * The Investigation Role's ARN.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-crossaccountconfiguration.html#cfn-aiops-investigationgroup-crossaccountconfiguration-sourcerolearn
         */
        readonly sourceRoleArn?: string;
    }
}
/**
 * Properties for defining a `CfnInvestigationGroup`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html
 */
export interface CfnInvestigationGroupProps {
    /**
     * An array of key-value pairs of notification channels to apply to this resource.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-chatbotnotificationchannels
     */
    readonly chatbotNotificationChannels?: Array<CfnInvestigationGroup.ChatbotNotificationChannelProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * An array of cross account configurations.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-crossaccountconfigurations
     */
    readonly crossAccountConfigurations?: Array<CfnInvestigationGroup.CrossAccountConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-encryptionconfig
     */
    readonly encryptionConfig?: CfnInvestigationGroup.EncryptionConfigMapProperty | cdk.IResolvable;
    /**
     * Investigation Group policy.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-investigationgrouppolicy
     */
    readonly investigationGroupPolicy?: string;
    /**
     * Flag to enable cloud trail history.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-iscloudtraileventhistoryenabled
     */
    readonly isCloudTrailEventHistoryEnabled?: boolean | cdk.IResolvable;
    /**
     * User friendly name for resources.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-name
     */
    readonly name: string;
    /**
     * The number of days to retain the investigation group.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-retentionindays
     */
    readonly retentionInDays?: number;
    /**
     * The Investigation Role's ARN.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-rolearn
     */
    readonly roleArn?: string;
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-tagkeyboundaries
     */
    readonly tagKeyBoundaries?: Array<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
}
